
# Example: issue with labels!

*[ribbity-org/ribbity-test-repo#7](https://github.com/ribbity-org/ribbity-test-repo/issues/7)*

---

this issue has labels.



## Categories

This example belongs to the following categories:

 * [This issue or pull request already exists](l-duplicate.md)
 * [Good for newcomers](l-good first issue.md)


